OC.L10N.register(
    "logreader",
    {
    "Time" : "Tempore",
    "Info" : "Info",
    "Warning" : "Aviso",
    "Error" : "Error",
    "Copy" : "Copiar"
},
"nplurals=2; plural=(n != 1);");
